From: Corrado Zoccolo <czoccolo@gmail.com>
To: "jmoyer@redhat.com" <jmoyer@redhat.com>, Vivek Goyal <vgoyal@redhat.com>
Cc: "Zhang, Yanmin" <yanmin_zhang@linux.intel.com>,
Jens Axboe <jens.axboe@oracle.com>,
Shaohua Li <shaohua.li@intel.com>,
LKML <linux-kernel@vger.kernel.org>
Subject: Re: fio mmap randread 64k more than 40% regression with 2.6.33-rc1
Date: Tue, 19 Jan 2010 21:10:33 +0100 [thread overview]
Message-ID: <4e5e476b1001191210s37423e4av6673225d5078a88e@mail.gmail.com> (raw)
In-Reply-To: <1263783999.12893.2.camel@localhost>
On Mon, Jan 18, 2010 at 4:06 AM, Zhang, Yanmin
<yanmin_zhang@linux.intel.com> wrote:
> On Sat, 2010-01-16 at 17:27 +0100, Corrado Zoccolo wrote:
>> Hi Yanmin
>> On Mon, Jan 4, 2010 at 7:28 PM, Corrado Zoccolo <czoccolo@gmail.com> wrote:
>> > Hi Yanmin,
>> >> When low_latency=1, we get the biggest number with kernel 2.6.32.
>> >> Comparing with low_latency=0's result, the prior one is about 4% better.
>> > Ok, so 2.6.33 + corrado (with low_latency =0) is comparable with
>> > fastest 2.6.32, so we can consider the first part of the problem
>> > solved.
>> >
>> I think we can return now to your full script with queue merging.
>> I'm wondering if (in arm_slice_timer):
>> - if (cfqq->dispatched)
>> + if (cfqq->dispatched || (cfqq->new_cfqq && rq_in_driver(cfqd)))
>> return;
>> gives the same improvement you were experiencing just reverting to rq_in_driver.
> I did a quick testing against 2.6.33-rc1. With the new method, fio mmap randread 46k
> has about 20% improvement. With just checking rq_in_driver(cfqd), it has
> about 33% improvement.
>
Jeff, do you have an idea why in arm_slice_timer, checking
rq_in_driver instead of cfqq->dispatched gives so much improvement in
presence of queue merging, while it doesn't have noticeable effect
when there are no merges?
Thanks,
Corrado
>
>>
>> We saw that cfqq->dispatched worked fine when there was no queue
>> merging happening, so it must be something concerning merging,
>> probably dispatched is not accurate when we set up for a merging, but
>> the merging was not yet done.
>
>
>
next prev parent reply other threads:[~2010-01-19 20:10 UTC|newest]
Thread overview: 17+ messages / expand[flat|nested] mbox.gz Atom feed top
2009-12-31 9:16 Zhang, Yanmin
2009-12-31 10:34 ` Corrado Zoccolo
2010-01-01 10:12 ` Zhang, Yanmin
2010-01-01 16:32 ` Corrado Zoccolo
2010-01-02 12:33 ` Zhang, Yanmin
2010-01-02 18:52 ` Corrado Zoccolo
2010-01-04 8:18 ` Zhang, Yanmin
2010-01-04 18:28 ` Corrado Zoccolo
2010-01-16 16:27 ` Corrado Zoccolo
2010-01-18 3:06 ` Zhang, Yanmin
2010-01-19 20:10 ` Corrado Zoccolo [this message]
2010-01-19 20:42 ` Jeff Moyer
2010-01-19 21:40 ` Vivek Goyal
2010-01-19 21:58 ` Corrado Zoccolo
2010-01-20 19:18 ` Vivek Goyal
2010-01-20 1:29 ` Shaohua Li
2010-01-20 14:00 ` Jeff Moyer
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=4e5e476b1001191210s37423e4av6673225d5078a88e@mail.gmail.com \
--to=czoccolo@gmail.com \
--cc=jens.axboe@oracle.com \
--cc=jmoyer@redhat.com \
--cc=linux-kernel@vger.kernel.org \
--cc=shaohua.li@intel.com \
--cc=vgoyal@redhat.com \
--cc=yanmin_zhang@linux.intel.com \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox
all inboxes | Powered by JetHome®